@@ -3,6 +3,9 @@ class BillingStatementEntity:
         data = api_resource.data
 
         self.id = data.get('id')
+        self.billing_details_collection = data.get('billing_details_collection')
+        self.billing_statement_merchant_name = data.get('billing_statement_merchant_name')
+        self.billing_statement_number = data.get('billing_statement_number')
         self.customer_reference_id = data.get('customer_reference_id')
         self.client_secret = data.get('client_secret')
         self.status = data.get('status')
@@ -15,8 +18,9 @@ class BillingStatementEntity:
         self.success_url = data.get('success_url')
         self.cancel_url = data.get('cancel_url')
         self.payment_methods = data.get('payment_methods')
+        self.statement_descriptor = data.get('statement_descriptor')
         self.description = data.get('description')
         self.submit_type = data.get('submit_type')
         self.expires_at = data.get('expires_at')
         self.created_at = data.get('created_at')
-        self.updated_at = data.get('updated_at')
\ No newline at end of file
+        self.updated_at = data.get('updated_at')
